@@ -1,10 +1,5 @@
 package App::ListOrgHeadlines;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-04'; # DATE
-our $DIST = 'App-OrgUtils'; # DIST
-our $VERSION = '0.482'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -15,10 +10,14 @@ use App::OrgUtils;
 use Cwd qw(abs_path);
 use DateTime;
 use Digest::MD5 qw(md5_hex);
+use Exporter 'import';
 use List::MoreUtils qw(uniq);
 
-require Exporter;
-our @ISA       = qw(Exporter);
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-10-11'; # DATE
+our $DIST = 'App-OrgUtils'; # DIST
+our $VERSION = '0.483'; # VERSION
+
 our @EXPORT_OK = qw(list_org_headlines);
 
 our %SPEC;
@@ -421,7 +420,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.482 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2021-07-04.
+This document describes version 0.483 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2022-10-11.
 
 =head1 SYNOPSIS
 
@@ -588,6 +587,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-OrgUtils>
@@ -596,15 +624,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
